@@ -1,7 +1,7 @@
 extern crate xmlparser as xml;
 
 #[macro_use] mod token;
-use token::*;
+use crate::token::*;
 
 test!(pi_01, "<?xslt ma?>",
     Token::PI("xslt", Some("ma"), 0..11)
@@ -24,7 +24,7 @@ test!(pi_05, "<?xml-stylesheet?>",
 );
 
 test!(pi_err_01, "<??xml \t\n m?>",
-    Token::Error("invalid token 'Processing Instruction' at 1:1 cause invalid name token".to_string())
+    Token::Error("invalid processing instruction at 1:1 cause invalid name token".to_string())
 );
 
 test!(declaration_01, "<?xml version=\"1.0\"?>",
@@ -69,70 +69,70 @@ test!(declaration_10, "<?xml version='1.0' standalone='no' ?>",
 
 // Declaration with an invalid order
 test!(declaration_err_01, "<?xml encoding='UTF-8' version='1.0'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected 'version' at 1:7".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected 'version' at 1:7".to_string())
 );
 
 test!(declaration_err_02, "<?xml version='1.0' encoding='*invalid*'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected '\'' not '*' at 1:31".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected '\'' not '*' at 1:31".to_string())
 );
 
 test!(declaration_err_03, "<?xml version='2.0'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected '1.' at 1:16".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected '1.' at 1:16".to_string())
 );
 
 test!(declaration_err_04, "<?xml version='1.0' standalone='true'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected 'yes', 'no' at 1:33".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected 'yes', 'no' at 1:33".to_string())
 );
 
 test!(declaration_err_05, "<?xml version='1.0' yes='true'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected '?>' at 1:21".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected '?>' at 1:21".to_string())
 );
 
 test!(declaration_err_06, "<?xml version='1.0' encoding='UTF-8' standalone='yes' yes='true'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected '?>' at 1:55".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected '?>' at 1:55".to_string())
 );
 
 test!(declaration_err_07, "\u{000a}<?xml\u{000a}&jg'];",
-    Token::Error("invalid token 'Processing Instruction' at 2:1 cause expected '?>' at 3:7".to_string())
+    Token::Error("invalid processing instruction at 2:1 cause expected '?>' at 3:7".to_string())
 );
 
 test!(declaration_err_08, "<?xml \t\n ?m?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected 'version' at 2:2".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected 'version' at 2:2".to_string())
 );
 
 test!(declaration_err_09, "<?xml \t\n m?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected 'version' at 2:2".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected 'version' at 2:2".to_string())
 );
 
 // XML declaration allowed only at the start of the document.
 test!(declaration_err_10, " <?xml version='1.0'?>",
-    Token::Error("unexpected token 'Declaration' at 1:2".to_string())
+    Token::Error("unknown token at 1:2".to_string())
 );
 
 // XML declaration allowed only at the start of the document.
 test!(declaration_err_11, "<!-- comment --><?xml version='1.0'?>",
     Token::Comment(" comment ", 0..16),
-    Token::Error("unexpected token 'Declaration' at 1:17".to_string())
+    Token::Error("unknown token at 1:17".to_string())
 );
 
 // Duplicate.
 test!(declaration_err_12, "<?xml version='1.0'?><?xml version='1.0'?>",
     Token::Declaration("1.0", None, None, 0..21),
-    Token::Error("unexpected token 'Declaration' at 1:22".to_string())
+    Token::Error("unknown token at 1:22".to_string())
 );
 
 test!(declaration_err_13, "<?target \u{0000}content>",
-    Token::Error("invalid token 'Processing Instruction' at 1:1 cause a non-XML character '\\u{0}' found at 1:10".to_string())
+    Token::Error("invalid processing instruction at 1:1 cause a non-XML character '\\u{0}' found at 1:10".to_string())
 );
 
 test!(declaration_err_14, "<?xml version='1.0'encoding='UTF-8'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected space not 'e' at 1:20".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected space not 'e' at 1:20".to_string())
 );
 
 test!(declaration_err_15, "<?xml version='1.0' encoding='UTF-8'standalone='yes'?>",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected space not 's' at 1:37".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected space not 's' at 1:37".to_string())
 );
 
 test!(declaration_err_16, "<?xml version='1.0'",
-    Token::Error("invalid token 'Declaration' at 1:1 cause expected '?>' at 1:20".to_string())
+    Token::Error("invalid XML declaration at 1:1 cause expected '?>' at 1:20".to_string())
 );
